import { objectReduce } from 'fast-loops'
import { className, mergeData, renderRule, validate } from '../../core/utils'
import LOGOS from '../../core/logos'
import rules from './logo.rules'

const NAMES = Object.keys(LOGOS)

const getFill = (fills, fill, key) =>
  (fills ? fills[key] || fill : fill)

const renderPath = (h, ctx) => {
  const { fills } = ctx.props
  return (paths, path, key) => {
    const fill = getFill(fills, path.fill, key)
    const attrs = { fill, d: path.path }
    paths.push(h('path', { attrs, key }))
    return paths
  }
}

export default {
  functional: true,
  inject: [
    'fela',
    'croudClassName'
  ],
  props: {
    name: {
      type: String,
      enums: NAMES,
      required: true,
      validator: validate(NAMES)
    },
    display: {
      type: String,
      default: 'block'
    },
    scale: {
      type: Number,
      default: 1
    },
    fills: {
      type: Object
    }
  },
  render(h, ctx) {
    const { name, scale } = ctx.props
    const { paths, width, height } = LOGOS[name]
    const classes = renderRule(ctx, rules.logo)
    const children = objectReduce(paths, renderPath(h, ctx), [])
    return h('svg', mergeData(ctx, {
      class: className(ctx, 'logo', classes),
      attrs: {
        xmlns: 'http://www.w3.org/2000/svg',
        viewBox: `0 0 ${width} ${height}`,
        height: height * scale,
        width: width * scale
      }
    }), children)
  }
}
